@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -16,14 +14,17 @@
 #    under the License.
 
 import netaddr
+from six import iteritems
 import webob.exc
 
+from oslo_log import log as logging
+from oslo_utils import strutils
+
 from tacker.api import api_common
 from tacker.api.v1 import attributes
 from tacker.api.v1 import resource as wsgi_resource
 from tacker.common import exceptions
 from tacker.common import rpc as n_rpc
-from tacker.openstack.common import log as logging
 from tacker import policy
 
 
@@ -49,8 +50,7 @@ class Controller(object):
     def __init__(self, plugin, collection, resource, attr_info,
                  allow_bulk=False, member_actions=None, parent=None,
                  allow_pagination=False, allow_sorting=False):
-        if member_actions is None:
-            member_actions = []
+        member_actions = member_actions or []
         self._plugin = plugin
         self._collection = collection.replace('-', '_')
         self._resource = resource.replace('-', '_')
@@ -92,7 +92,7 @@ class Controller(object):
                                                          self._resource)
 
     def _get_primary_key(self, default_primary_key='id'):
-        for key, value in self._attr_info.iteritems():
+        for key, value in iteritems(self._attr_info):
             if value.get('primary_key', False):
                 return key
         return default_primary_key
@@ -152,7 +152,7 @@ class Controller(object):
     def _filter_attributes(self, context, data, fields_to_strip=None):
         if not fields_to_strip:
             return data
-        return dict(item for item in data.iteritems()
+        return dict(item for item in iteritems(data)
                     if (item[0] not in fields_to_strip))
 
     def _do_field_list(self, original_fields):
@@ -321,7 +321,7 @@ class Controller(object):
             return objs
         # Note(salvatore-orlando): broad catch as in theory a plugin
         # could raise any kind of exception
-        except Exception as ex:
+        except Exception:
             for obj in objs:
                 obj_deleter = getattr(self._plugin,
                                       self._plugin_handlers[self.DELETE])
@@ -339,7 +339,7 @@ class Controller(object):
             # plugin raised might have been created or not in the db.
             # We need a way for ensuring that if it has been created,
             # it is then deleted
-            raise ex
+            raise
 
     def create(self, request, body=None, **kwargs):
         """Creates a new instance of the requested entity."""
@@ -443,7 +443,7 @@ class Controller(object):
         # Load object to check authz
         # but pass only attributes in the original body and required
         # by the policy engine to the policy 'brain'
-        field_list = [name for (name, value) in self._attr_info.iteritems()
+        field_list = [name for (name, value) in iteritems(self._attr_info)
                       if (value.get('required_by_policy') or
                           value.get('primary_key') or
                           'default' not in value)]
@@ -506,7 +506,8 @@ class Controller(object):
         if not body:
             raise webob.exc.HTTPBadRequest(_("Resource body required"))
 
-        LOG.debug(_("Request body: %(body)s"), {'body': body})
+        LOG.debug(_("Request body: %(body)s"), {'body':
+                                               strutils.mask_password(body)})
         prep_req_body = lambda x: Controller.prepare_request_body(
             context,
             x if resource in x else {resource: x},
@@ -532,7 +533,7 @@ class Controller(object):
         Controller._verify_attributes(res_dict, attr_info)
 
         if is_create:  # POST
-            for attr, attr_vals in attr_info.iteritems():
+            for attr, attr_vals in iteritems(attr_info):
                 if attr_vals['allow_post']:
                     if ('default' not in attr_vals and
                             attr not in res_dict):
@@ -546,12 +547,12 @@ class Controller(object):
                         msg = _("Attribute '%s' not allowed in POST") % attr
                         raise webob.exc.HTTPBadRequest(msg)
         else:  # PUT
-            for attr, attr_vals in attr_info.iteritems():
+            for attr, attr_vals in iteritems(attr_info):
                 if attr in res_dict and not attr_vals['allow_put']:
                     msg = _("Cannot update read-only attribute %s") % attr
                     raise webob.exc.HTTPBadRequest(msg)
 
-        for attr, attr_vals in attr_info.iteritems():
+        for attr, attr_vals in iteritems(attr_info):
             if (attr not in res_dict or
                     res_dict[attr] is attributes.ATTR_NOT_SPECIFIED):
                 continue
