@@ -23,7 +23,8 @@ Based on this comparison database can be healed with healing migration.
 
 from tacker.db import model_base
 from tacker.db.nfvo import nfvo_db  # noqa
-from tacker.db.vm import vm_db  # noqa
+from tacker.db.nfvo import vnffg_db  # noqa
+from tacker.db.vnfm import vnfm_db  # noqa
 
 
 def get_metadata():
