@@ -90,3 +90,14 @@ class VimAbstractDriver(extensions.PluginInterface):
         Checks the health status of VIM and return a boolean value
         """
         pass
+
+    @abc.abstractmethod
+    def get_vim_resource_id(self, vim_obj, resource_type, resource_name):
+        """Parses a VIM resource ID from a given type and name
+
+        :param vim_obj: VIM information
+        :param resource_type: type of resource, such as network, compute
+        :param resource_name: name of resource, such at "test-network"
+        :return: ID of of resource
+        """
+        pass
