@@ -12,9 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import yaml
+
 from novaclient import exceptions
 from oslo_config import cfg
 
+from tacker.plugins.common import constants as evt_constants
 from tacker.tests import constants
 from tacker.tests.functional import base
 from tacker.tests.utils import read_file
@@ -25,12 +28,12 @@ VNF_CIRROS_CREATE_TIMEOUT = 120
 
 
 class VnfTestToscaCreate(base.BaseTackerTest):
-    def test_create_delete_vnf_tosca_no_monitoring(self):
+    def _test_create_vnf(self, vnfd_file, vnf_name):
         data = dict()
-        data['tosca'] = read_file('sample-tosca-vnfd.yaml')
-        vnfd_name = 'test_tosca_vnf_with_cirros_no_monitoring'
+        values_str = read_file(vnfd_file)
+        data['tosca'] = values_str
         toscal = data['tosca']
-        tosca_arg = {'vnfd': {'name': vnfd_name,
+        tosca_arg = {'vnfd': {'name': vnf_name,
                               'attributes': {'vnfd': toscal}}}
 
         # Create vnfd with tosca template
@@ -39,40 +42,97 @@ class VnfTestToscaCreate(base.BaseTackerTest):
 
         # Create vnf with vnfd_id
         vnfd_id = vnfd_instance['vnfd']['id']
-        vnf_name = 'test_tosca_vnf_with_cirros_no_monitoring'
         vnf_arg = {'vnf': {'vnfd_id': vnfd_id, 'name': vnf_name}}
         vnf_instance = self.client.create_vnf(body=vnf_arg)
 
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
 
         vnf_id = vnf_instance['vnf']['id']
-        vnf_current_status = self.wait_until_vnf_active(
+        self.wait_until_vnf_active(
             vnf_id,
             constants.VNF_CIRROS_CREATE_TIMEOUT,
             constants.ACTIVE_SLEEP_TIME)
-        self.assertEqual('ACTIVE', vnf_current_status)
-        self.assertIsNotNone(self.client.show_vnf(vnf_id)['vnf']['mgmt_url'])
+        vnf_show_out = self.client.show_vnf(vnf_id)['vnf']
+        self.assertIsNotNone(vnf_show_out['mgmt_url'])
 
+        input_dict = yaml.load(values_str)
+        prop_dict = input_dict['topology_template']['node_templates'][
+            'CP1']['properties']
+
+        # Verify if ip_address is static, it is same as in show_vnf
+        if prop_dict.get('ip_address'):
+            mgmt_url_input = prop_dict.get('ip_address')
+            mgmt_info = yaml.load(
+                vnf_show_out['mgmt_url'])
+            self.assertEqual(mgmt_url_input, mgmt_info['VDU1'])
+
+        # Verify anti spoofing settings
+        stack_id = vnf_show_out['instance_id']
+        template_dict = input_dict['topology_template']['node_templates']
+        for field in template_dict.keys():
+            prop_dict = template_dict[field]['properties']
+            if prop_dict.get('anti_spoofing_protection'):
+                self.verify_antispoofing_in_stack(stack_id=stack_id,
+                                                  resource_name=field)
+
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.PENDING_CREATE,
+            vnf_instance['vnf'][evt_constants.RES_EVT_CREATED_FLD])
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.ACTIVE)
+        return vnfd_id, vnf_id
+
+    def _test_delete_vnf(self, vnf_id):
         # Delete vnf_instance with vnf_id
         try:
             self.client.delete_vnf(vnf_id)
         except Exception:
             assert False, "vnf Delete failed"
 
+        self.wait_until_vnf_delete(vnf_id,
+                                   constants.VNF_CIRROS_DELETE_TIMEOUT)
+        self.verify_vnf_crud_events(vnf_id, evt_constants.RES_EVT_DELETE,
+                                    evt_constants.PENDING_DELETE, cnt=2)
+
+    def _test_cleanup_vnfd(self, vnfd_id, vnf_id):
         # Delete vnfd_instance
         self.addCleanup(self.client.delete_vnfd, vnfd_id)
         self.addCleanup(self.wait_until_vnf_delete, vnf_id,
             constants.VNF_CIRROS_DELETE_TIMEOUT)
 
+    def test_create_delete_vnf_tosca(self):
+        vnfd_id, vnf_id = self._test_create_vnf(
+            'sample-tosca-vnfd.yaml',
+            'test_tosca_vnf_with_cirros')
+        servers = self.novaclient().servers.list()
+        vdus = []
+        for server in servers:
+            vdus.append(server.name)
+        self.assertIn('test-vdu', vdus)
+
+        port_list = self.neutronclient().list_ports()['ports']
+        vdu_ports = []
+        for port in port_list:
+            vdu_ports.append(port['name'])
+        self.assertIn('test-cp', vdu_ports)
+        self._test_delete_vnf(vnf_id)
+        self._test_cleanup_vnfd(vnfd_id, vnf_id)
+
+    def test_create_delete_vnf_static_ip(self):
+        vnfd_id, vnf_id = self._test_create_vnf(
+            'sample-tosca-vnfd-static-ip.yaml',
+            'test_tosca_vnf_with_cirros_no_monitoring')
+        self._test_delete_vnf(vnf_id)
+        self._test_cleanup_vnfd(vnfd_id, vnf_id)
+
 
 class VnfTestToscaCreateFlavorCreation(base.BaseTackerTest):
     def test_create_delete_vnf_tosca_no_monitoring(self):
-        data = dict()
         vnfd_name = 'tosca_vnfd_with_auto_flavor'
-        data['tosca'] = read_file('sample-tosca-vnfd-flavor.yaml')
-        toscal = data['tosca']
+        input_yaml = read_file('sample-tosca-vnfd-flavor.yaml')
+        tosca_dict = yaml.safe_load(input_yaml)
         tosca_arg = {'vnfd': {'name': vnfd_name, 'attributes': {'vnfd':
-                                                                toscal}}}
+                                                                tosca_dict}}}
 
         # Create vnfd with tosca template
         vnfd_instance = self.client.create_vnfd(body=tosca_arg)
@@ -87,13 +147,18 @@ class VnfTestToscaCreateFlavorCreation(base.BaseTackerTest):
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
 
         vnf_id = vnf_instance['vnf']['id']
-        vnf_current_status = self.wait_until_vnf_active(
+        self.wait_until_vnf_active(
             vnf_id,
             constants.VNF_CIRROS_CREATE_TIMEOUT,
             constants.ACTIVE_SLEEP_TIME)
-        self.assertEqual('ACTIVE', vnf_current_status)
         self.assertIsNotNone(self.client.show_vnf(vnf_id)['vnf']['mgmt_url'])
 
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.PENDING_CREATE,
+            vnf_instance['vnf'][evt_constants.RES_EVT_CREATED_FLD])
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.ACTIVE)
+
         servers = self.novaclient().servers.list()
         vdu_server = None
         for server in servers:
@@ -112,22 +177,24 @@ class VnfTestToscaCreateFlavorCreation(base.BaseTackerTest):
         except Exception:
             assert False, "vnf Delete failed"
 
+        self.wait_until_vnf_delete(vnf_id,
+                                   constants.VNF_CIRROS_DELETE_TIMEOUT)
+        self.verify_vnf_crud_events(vnf_id, evt_constants.RES_EVT_DELETE,
+                                    evt_constants.PENDING_DELETE, cnt=2)
+
         # Delete vnfd_instance
         self.addCleanup(self.client.delete_vnfd, vnfd_id)
-        self.addCleanup(self.wait_until_vnf_delete, vnf_id,
-            constants.VNF_CIRROS_DELETE_TIMEOUT)
         self.assertRaises(exceptions.NotFound, nova_flavors.delete,
                           [flavor_id])
 
 
 class VnfTestToscaCreateImageCreation(base.BaseTackerTest):
     def test_create_delete_vnf_tosca_no_monitoring(self):
-        data = dict()
         vnfd_name = 'tosca_vnfd_with_auto_image'
-        data['tosca'] = read_file('sample-tosca-vnfd-image.yaml')
-        toscal = data['tosca']
+        input_yaml = read_file('sample-tosca-vnfd-image.yaml')
+        tosca_dict = yaml.safe_load(input_yaml)
         tosca_arg = {'vnfd': {'name': vnfd_name, 'attributes': {'vnfd':
-                                                                toscal}}}
+                                                                tosca_dict}}}
 
         # Create vnfd with tosca template
         vnfd_instance = self.client.create_vnfd(body=tosca_arg)
@@ -142,13 +209,18 @@ class VnfTestToscaCreateImageCreation(base.BaseTackerTest):
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
 
         vnf_id = vnf_instance['vnf']['id']
-        vnf_current_status = self.wait_until_vnf_active(
+        self.wait_until_vnf_active(
             vnf_id,
             constants.VNF_CIRROS_CREATE_TIMEOUT,
             constants.ACTIVE_SLEEP_TIME)
-        self.assertEqual('ACTIVE', vnf_current_status)
         self.assertIsNotNone(self.client.show_vnf(vnf_id)['vnf']['mgmt_url'])
 
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.PENDING_CREATE,
+            vnf_instance['vnf'][evt_constants.RES_EVT_CREATED_FLD])
+        self.verify_vnf_crud_events(
+            vnf_id, evt_constants.RES_EVT_CREATE, evt_constants.ACTIVE)
+
         servers = self.novaclient().servers.list()
         vdu_server = None
         for server in servers:
@@ -167,9 +239,12 @@ class VnfTestToscaCreateImageCreation(base.BaseTackerTest):
         except Exception:
             assert False, "vnf Delete failed"
 
+        self.wait_until_vnf_delete(vnf_id,
+                                   constants.VNF_CIRROS_DELETE_TIMEOUT)
+        self.verify_vnf_crud_events(vnf_id, evt_constants.RES_EVT_DELETE,
+                                    evt_constants.PENDING_DELETE, cnt=2)
+
         # Delete vnfd_instance
         self.addCleanup(self.client.delete_vnfd, vnfd_id)
-        self.addCleanup(self.wait_until_vnf_delete, vnf_id,
-            constants.VNF_CIRROS_DELETE_TIMEOUT)
         self.assertRaises(exceptions.NotFound, nova_images.delete,
                           [image_id])
